@@ -1,5 +1,5 @@
 /* Test of setting an ACL equivalent to a mode.
-   Copyright (C) 2008-2015 Free Software Foundation, Inc.
+   Copyright (C) 2008-2016 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 
 #include <stdlib.h>
 
-#include "progname.h"
 #include "macros.h"
 
 int
@@ -31,8 +30,6 @@ main (int argc, char *argv[])
   const char *file;
   int mode;
 
-  set_program_name (argv[0]);
-
   ASSERT (argc == 3);
 
   file = argv[1];
