@@ -1,5 +1,5 @@
 /* Removes leading and/or trailing whitespaces
-   Copyright (C) 2006, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (C) 2006, 2009-2016 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,13 +22,12 @@
 #define TRIM_BOTH 2
 
 /* Removes trailing and leading whitespaces. */
-#define trim(s) trim2((s), TRIM_BOTH)
+#define trim(s) trim2(s, TRIM_BOTH)
 
 /* Removes trailing whitespaces. */
-#define trim_trailing(s) trim2((s), TRIM_TRAILING)
+#define trim_trailing(s) trim2(s, TRIM_TRAILING)
 
 /* Removes leading whitespaces. */
-#define trim_leading(s) trim2((s), TRIM_LEADING)
-
-char *trim2(const char *, int);
+#define trim_leading(s) trim2(s, TRIM_LEADING)
 
+char *trim2 (const char *, int);
