@@ -18,6 +18,7 @@
 #include <sys/types.h>
 
 #include "system.h"
+#include "die.h"
 #include "error.h"
 #include "save-cwd.h"
 #include "xgetcwd.h"
@@ -102,8 +103,8 @@ done:
   {
     int save_errno = errno;
     if (restore_cwd (&cwd) != 0)
-      error (EXIT_FAILURE, errno,
-             _("failed to return to initial working directory"));
+      die (EXIT_FAILURE, errno,
+           _("failed to return to initial working directory"));
     free_cwd (&cwd);
     errno = save_errno;
   }
