@@ -23,6 +23,7 @@
 
 #include "system.h"
 #include "long-options.h"
+#include "die.h"
 #include "error.h"
 #include "quote.h"
 #include "xgethostname.h"
@@ -91,11 +92,11 @@ main (int argc, char **argv)
       /* Set hostname to operand.  */
       char const *name = argv[optind];
       if (sethostname (name, strlen (name)) != 0)
-        error (EXIT_FAILURE, errno, _("cannot set name to %s"),
-               quote (name));
+        die (EXIT_FAILURE, errno, _("cannot set name to %s"),
+             quote (name));
 #else
-      error (EXIT_FAILURE, 0,
-             _("cannot set hostname; this system lacks the functionality"));
+      die (EXIT_FAILURE, 0,
+           _("cannot set hostname; this system lacks the functionality"));
 #endif
     }
 
@@ -103,7 +104,7 @@ main (int argc, char **argv)
     {
       hostname = xgethostname ();
       if (hostname == NULL)
-        error (EXIT_FAILURE, errno, _("cannot determine hostname"));
+        die (EXIT_FAILURE, errno, _("cannot determine hostname"));
       printf ("%s\n", hostname);
     }
 
