@@ -1,5 +1,5 @@
 /* printf - format and print data
-   Copyright (C) 1990-2015 Free Software Foundation, Inc.
+   Copyright (C) 1990-2016 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,6 +41,10 @@
    %b = print an argument string, interpreting backslash escapes,
      except that octal escapes are of the form \0 or \0ooo.
 
+   %q = print an argument string in a format that can be
+     reused as shell input.  Escaped characters used the proposed
+     POSIX $'' syntax supported by most shells.
+
    The 'format' argument is re-used as many times as necessary
    to convert all of the given arguments.
 
@@ -52,6 +56,7 @@
 
 #include "system.h"
 #include "c-strtod.h"
+#include "die.h"
 #include "error.h"
 #include "quote.h"
 #include "unicodeio.h"
@@ -124,7 +129,9 @@ FORMAT controls the output as in C printf.  Interpreted sequences are:\n\
   %%      a single %\n\
   %b      ARGUMENT as a string with '\\' escapes interpreted,\n\
           except that octal escapes are of the form \\0 or \\0NNN\n\
-\n\
+  %q      ARGUMENT is printed in a format that can be reused as shell input,\n\
+          escaping non-printable characters with the proposed POSIX $'' syntax.\
+\n\n\
 and all C format specifications ending with one of diouxXfeEgGcs, with\n\
 ARGUMENTs converted to proper type first.  Variable widths are handled.\n\
 "), stdout);
@@ -139,15 +146,15 @@ verify_numeric (const char *s, const char *end)
 {
   if (errno)
     {
-      error (0, errno, "%s", s);
+      error (0, errno, "%s", quote (s));
       exit_status = EXIT_FAILURE;
     }
   else if (*end)
     {
       if (s == end)
-        error (0, 0, _("%s: expected a numeric value"), s);
+        error (0, 0, _("%s: expected a numeric value"), quote (s));
       else
-        error (0, 0, _("%s: value not completely converted"), s);
+        error (0, 0, _("%s: value not completely converted"), quote (s));
       exit_status = EXIT_FAILURE;
     }
 }
@@ -244,7 +251,7 @@ print_esc (const char *escstart, bool octal_0)
            ++esc_length, ++p)
         esc_value = esc_value * 16 + hextobin (*p);
       if (esc_length == 0)
-        error (EXIT_FAILURE, 0, _("missing hexadecimal number in escape"));
+        die (EXIT_FAILURE, 0, _("missing hexadecimal number in escape"));
       putchar (esc_value);
     }
   else if (isodigit (*p))
@@ -271,7 +278,7 @@ print_esc (const char *escstart, bool octal_0)
            --esc_length, ++p)
         {
           if (! isxdigit (to_uchar (*p)))
-            error (EXIT_FAILURE, 0, _("missing hexadecimal number in escape"));
+            die (EXIT_FAILURE, 0, _("missing hexadecimal number in escape"));
           uni_value = uni_value * 16 + hextobin (*p);
         }
 
@@ -283,8 +290,8 @@ print_esc (const char *escstart, bool octal_0)
       if ((uni_value <= 0x9f
            && uni_value != 0x24 && uni_value != 0x40 && uni_value != 0x60)
           || (uni_value >= 0xd800 && uni_value <= 0xdfff))
-        error (EXIT_FAILURE, 0, _("invalid universal character name \\%c%0*x"),
-               esc_char, (esc_char == 'u' ? 4 : 8), uni_value);
+        die (EXIT_FAILURE, 0, _("invalid universal character name \\%c%0*x"),
+             esc_char, (esc_char == 'u' ? 4 : 8), uni_value);
 
       print_unicode_char (stdout, uni_value, 0);
     }
@@ -506,6 +513,18 @@ print_formatted (const char *format, int argc, char **argv)
               break;
             }
 
+          if (*f == 'q')
+            {
+              if (argc > 0)
+                {
+                  fputs (quotearg_style (shell_escape_quoting_style, *argv),
+                         stdout);
+                  ++argv;
+                  --argc;
+                }
+              break;
+            }
+
           memset (ok, 0, sizeof ok);
           ok['a'] = ok['A'] = ok['c'] = ok['d'] = ok['e'] = ok['E'] =
             ok['f'] = ok['F'] = ok['g'] = ok['G'] = ok['i'] = ok['o'] =
@@ -544,8 +563,8 @@ print_formatted (const char *format, int argc, char **argv)
                   if (INT_MIN <= width && width <= INT_MAX)
                     field_width = width;
                   else
-                    error (EXIT_FAILURE, 0, _("invalid field width: %s"),
-                           *argv);
+                    die (EXIT_FAILURE, 0, _("invalid field width: %s"),
+                         quote (*argv));
                   ++argv;
                   --argc;
                 }
@@ -579,8 +598,8 @@ print_formatted (const char *format, int argc, char **argv)
                           precision = -1;
                         }
                       else if (INT_MAX < prec)
-                        error (EXIT_FAILURE, 0, _("invalid precision: %s"),
-                               *argv);
+                        die (EXIT_FAILURE, 0, _("invalid precision: %s"),
+                             quote (*argv));
                       else
                         precision = prec;
                       ++argv;
@@ -605,9 +624,9 @@ print_formatted (const char *format, int argc, char **argv)
           {
             unsigned char conversion = *f;
             if (! ok[conversion])
-              error (EXIT_FAILURE, 0,
-                     _("%.*s: invalid conversion specification"),
-                     (int) (f + 1 - direc_start), direc_start);
+              die (EXIT_FAILURE, 0,
+                   _("%.*s: invalid conversion specification"),
+                   (int) (f + 1 - direc_start), direc_start);
           }
 
           print_direc (direc_start, direc_length, *f,
