@@ -1,7 +1,7 @@
-#! /bin/sh
+#!/bin/sh
 # Test -D option.
 
-# Copyright (C) 2000-2015 Free Software Foundation, Inc.
+# Copyright (C) 2000-2016 Free Software Foundation, Inc.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ print_ver_ ginstall
 
 
 file=file
-echo foo > $file
+echo foo > $file || framework_failure_
 
 # Before 4.0q, this would mistakenly create $file, not 'dest'
 # in no-dir1/no-dir2/.
@@ -32,4 +32,11 @@ ginstall -D $file no-dir1/no-dir2/dest || fail=1
 test -d no-dir1/no-dir2 || fail=1
 test -r no-dir1/no-dir2/dest || fail=1
 
+# Between 6.1 and 8.24, this would not copy $file
+# due to incorrectly modified working directory
+mkdir dir1 || framework_failure_
+touch dir1/file1 || framework_failure_
+ginstall -D "$PWD/dir1/file1" $file -t "$PWD/no-dir2/" || fail=1
+test -r no-dir2/$file && test -r no-dir2/file1 || fail=1
+
 Exit $fail
