@@ -1,8 +1,8 @@
-#! /bin/sh
+#!/bin/sh
 # Make sure all of these programs work properly
 # when invoked with --help or --version.
 
-# Copyright (C) 2000-2015 Free Software Foundation, Inc.
+# Copyright (C) 2000-2016 Free Software Foundation, Inc.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -85,19 +85,19 @@ for i in $built_programs; do
 
   # Make sure they fail upon 'disk full' error.
   if test -w /dev/full && test -c /dev/full; then
-    env $i --help    >/dev/full 2>/dev/null && fail=1
-    env $i --version >/dev/full 2>/dev/null && fail=1
-    status=$?
     test $i = [ && prog=lbracket || prog=$(echo $i|sed "s/$EXEEXT$//")
     eval "expected=\$expected_failure_status_$prog"
     test x$expected = x && expected=1
-    if test $status = $expected; then
-      : # ok
-    else
+
+    returns_ $expected env $i --help    >/dev/full 2>/dev/null &&
+    returns_ $expected env $i --version >/dev/full 2>/dev/null ||
+    {
       fail=1
+      env $i --help >/dev/full 2>/dev/null
+      status=$?
       echo "*** $i: bad exit status '$status' (expected $expected)," 1>&2
       echo "  with --help or --version output redirected to /dev/full" 1>&2
-    fi
+    }
   fi
 done
 
@@ -213,7 +213,8 @@ id_setup () { args=-u; }
 
 # Use env to avoid invoking built-in sleep of Solaris 11's /bin/sh.
 kill_setup () {
-  env sleep 10m & pid=$!
+  external=env
+  $external sleep 10m & pid=$!
   args=$pid
 }
 
