@@ -70,8 +70,7 @@ if test -w /dev/full && test -c /dev/full; then
 
   exec >/dev/tty
   test -t 1 || exit 0
-  nohup echo hi 2> /dev/full
-  test $? = 125 || fail=1
+  returns_ 125 nohup echo hi 2> /dev/full || fail=1
   test -f nohup.out || fail=1
   compare /dev/null nohup.out || fail=1
   rm -f nohup.out
@@ -118,9 +117,9 @@ EOF
 
 # Make sure it fails with exit status of 125 when given too few arguments,
 # except that POSIX requires 127 in this case.
-nohup >/dev/null 2>&1
-test $? = 125 || fail=1
-POSIXLY_CORRECT=1 nohup >/dev/null 2>&1
-test $? = 127 || fail=1
+returns_ 125 nohup >/dev/null 2>&1 || fail=1
+export POSIXLY_CORRECT=1
+returns_ 127 nohup >/dev/null 2>&1 || fail=1
+unset POSIXLY_CORRECT
 
 Exit $fail
