@@ -25,7 +25,7 @@ prog='env printf'
 $prog '%q\n' '' "'" a 'a b' '~a' 'a~' "$($prog %b 'a\r')" > out
 cat <<\EOF > exp || framework_failure_
 ''
-''\'''
+"'"
 a
 'a b'
 '~a'
@@ -42,13 +42,13 @@ if test "$LOCALE_FR_UTF8" != "none"; then
    #printable multi-byte
    LC_ALL=$f $prog '%q\n' 'áḃç' > out
    #non-printable multi-byte
-   LC_ALL=$f $prog '%q\n' "$(LC_ALL=$f $prog '\u0378')" >> out
+   LC_ALL=$f $prog '%q\n' "$($prog '\xc2\x81')" >> out
    #printable multi-byte in C locale
    LC_ALL=C $prog '%q\n' 'áḃç' >> out
   )
   cat <<\EOF > exp || framework_failure_
 áḃç
-''$'\315\270'
+''$'\302\201'
 ''$'\303\241\341\270\203\303\247'
 EOF
   compare exp out || fail=1
