@@ -50,4 +50,17 @@ for mode in '' '---disable-inotify'; do
   cleanup_
 done
 
+
+# Before coreutils-8.26 this would induce an UMR under UBSAN
+returns_ 1 timeout 10 tail -f - <&- 2>errt || fail=1
+cat <<\EOF >exp || framework_failure_
+tail: cannot fstat 'standard input'
+tail: error reading 'standard input'
+tail: no files remaining
+tail: -
+EOF
+sed 's/\(tail:.*\):.*/\1/' errt > err || framework_failure_
+compare exp err || fail=1
+
+
 Exit $fail
